tests Package
=============

:mod:`runtests` Module
----------------------

.. automodule:: stoq.tests.runtests
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    stoq.tests.gui

